@@ -13,6 +13,7 @@ import esppy
 import json
 import time
 import csv
+import ssl
 import six
 import re
 import os
@@ -36,7 +37,15 @@ class Connection(tools.Options):
         s = url[1].split(":")
 
         self._host = s[0]
-        self._port = s[1]
+
+        if len(s) == 2:
+            self._port = s[1]
+        elif self._secure:
+            self._port = 443
+        else:
+            self._port = 80
+
+        self._path = url[2]
 
         self._websocket = None
         self._handshakeComplete = False
@@ -61,7 +70,7 @@ class Connection(tools.Options):
         if auth.isEnabled:
             headers.append(("Authorization",auth.authorization))
 
-        ws = esppy.websocket.WebSocketClient(url,on_message=self.on_message,on_data=self.on_data,on_error=self.on_error,on_open=self.on_open,on_close=self.on_close,headers=headers)
+        ws = esppy.websocket.WebSocketClient(url,self._session,on_message=self.on_message,on_data=self.on_data,on_error=self.on_error,on_open=self.on_open,on_close=self.on_close,headers=headers)
         ws.connect()
 
     def stop(self):
@@ -76,13 +85,12 @@ class Connection(tools.Options):
 
     def send(self,data):
         if self._websocket != None:
-            #logging.info("SEND: " + str(data))
             self._websocket.send(str(data))
 
     def sendBinary(self,o):
         if self._websocket != None:
             encoder = codec.JsonEncoder(o)
-            self._websocket.send(encoder.data,True)
+            self._websocket.send(encoder.data)
 
     def getUrl(self):
         return(None)
@@ -238,8 +246,9 @@ class ServerConnection(Connection):
         "text-topic":"textanalytics"
     }
 
-    def __init__(self,session,delegate,**kwargs):
+    def __init__(self,session,k8s,delegate,**kwargs):
         Connection.__init__(self,session,**kwargs)
+        self._k8s = k8s
         self._delegate = delegate
         self._datasources = {}
         self._publishers = {}
@@ -254,8 +263,6 @@ class ServerConnection(Connection):
             Connection.message(self,message)
             return
 
-        #logging.info("MSG: " + message)
-
         xml = None
         o = None
 
@@ -348,13 +355,16 @@ class ServerConnection(Connection):
         url += "://"
         url += self.getHost()
         url += ":"
-        url += self.getPort()
-        url += "/eventStreamProcessing/v2/connect"
+        url += str(self.getPort())
+        if self._path != None:
+            url += self._path
+        else:
+            url += "/"
+        url += "eventStreamProcessing/v1/connect"
         return(url)
 
     def getEventCollection(self,path,**kwargs):
         ec = EventCollection(self,path,**kwargs)
-        #print("MESSAGE: " + Resources.getInstance().getText("testmsg"))
         self._datasources[ec._id] = ec
         if self.isHandshakeComplete:
             ec.open()
@@ -569,7 +579,6 @@ class ServerConnection(Connection):
             thread.start()
 
     def reconnect(self):
-        logging.info("RECONNECT")
         while self.isConnected == False:
             #time.sleep(5)
             #time.sleep(1)
@@ -1069,13 +1078,20 @@ class EventCollection(Datasource):
             return
 
         events = []
-        entries = data["entries"]
+        entries = None
+
+        if "entries" in data:
+            entries = data["entries"]
 
         if entries != None:
             for e in entries:
+                if "event" in e:
+                    event = e["event"]
+                else:
+                    event = e
                 o = {}
-                for k in e:
-                    o[k] = e[k]
+                for k in event:
+                    o[k] = event[k]
 
                 if "@opcode" in o == False:
                     o["@opcode"] = "insert"
@@ -1095,8 +1111,8 @@ class EventCollection(Datasource):
 
     def info(self,data):
         if "page" in data:
-            self._page = data["page"]
-            self._pages = data["pages"]
+            self._page = int(data["page"])
+            self._pages = int(data["pages"])
             self.deliverInfoChange()
 
     def process(self,events,clear):
@@ -1316,10 +1332,10 @@ class EventStream(Datasource):
         if "entries" in data == False:
             return
 
-        entries = data["entries"]
         events = []
 
-        if entries != None:
+        if "entries" in data:
+            entries = data["entries"]
             ignoreDeletes = self.getOpt("ignore_deletes",False)
 
             for e in entries:
@@ -1492,7 +1508,7 @@ class Publisher(tools.Options):
             o["id"] = self._id
             o["action"] = "publish"
             o["data"] = self._data
-            if self.getOpt("binary",True):
+            if self.getOpt("binary",False):
                 self._connection.sendBinary(json)
             else:
                 self._connection.send(json)
